.. pytest-phmdoctest documentation top level file.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pytest-phmdoctest 1.0.0
=======================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   doc/recent_changes
   CONTRIBUTING

Search
======

* :ref:`search`
